@@ -23,7 +23,7 @@ from infrahub import config
 from infrahub.core import registry
 from infrahub.core.graph import GRAPH_VERSION
 from infrahub.core.graph.constraints import ConstraintManagerBase, ConstraintManagerMemgraph, ConstraintManagerNeo4j
-from infrahub.core.graph.index import attr_value_index, node_indexes, rel_indexes
+from infrahub.core.graph.index import node_indexes, rel_indexes
 from infrahub.core.graph.schema import (
     GRAPH_SCHEMA,
     GraphAttributeProperties,
@@ -51,9 +51,6 @@ from infrahub.database import DatabaseType
 from infrahub.database.memgraph import IndexManagerMemgraph
 from infrahub.database.neo4j import IndexManagerNeo4j
 from infrahub.log import get_logger
-from infrahub.services import InfrahubServices
-from infrahub.services.adapters.message_bus.local import BusSimulator
-from infrahub.services.adapters.workflow.local import WorkflowLocalExecution
 
 from .constants import ERROR_BADGE, FAILED_BADGE, SUCCESS_BADGE
 from .db_commands.check_inheritance import check_inheritance
@@ -220,12 +217,8 @@ async def update_core_schema_cmd(
     context: CliContext = ctx.obj
     dbdriver = await context.init_db(retry=1)
 
-    service = await InfrahubServices.new(
-        database=dbdriver, message_bus=BusSimulator(), workflow=WorkflowLocalExecution()
-    )
-
     with prefect_test_harness():
-        await update_core_schema(db=dbdriver, service=service, initialize=True, debug=debug)
+        await update_core_schema(db=dbdriver, initialize=True, debug=debug)
 
     await dbdriver.close()
 
@@ -289,8 +282,6 @@ async def index(
         index_manager: IndexManagerBase = IndexManagerMemgraph(db=dbdriver)
     index_manager = IndexManagerNeo4j(db=dbdriver)
 
-    if config.SETTINGS.experimental_features.value_db_index:
-        node_indexes.append(attr_value_index)
     index_manager.init(nodes=node_indexes, rels=rel_indexes)
 
     if action == IndexAction.ADD:
@@ -393,9 +384,7 @@ async def initialize_internal_schema() -> None:
     registry.schema.register_schema(schema=schema)
 
 
-async def update_core_schema(
-    db: InfrahubDatabase, service: InfrahubServices, initialize: bool = True, debug: bool = False
-) -> None:
+async def update_core_schema(db: InfrahubDatabase, initialize: bool = True, debug: bool = False) -> None:
     """Update the core schema of Infrahub to the latest version"""
     # ----------------------------------------------------------
     # Initialize Schema and Registry
@@ -444,7 +433,7 @@ async def update_core_schema(
         schema_branch=candidate_schema,
         constraints=result.constraints,
     )
-    responses = await schema_validate_migrations(message=validate_migration_data, service=service)
+    responses = await schema_validate_migrations(message=validate_migration_data)
     error_messages = [violation.message for response in responses for violation in response.violations]
     if error_messages:
         rprint(f"{ERROR_BADGE} | Unable to update the schema, due to failed validations")
@@ -486,7 +475,7 @@ async def update_core_schema(
         previous_schema=origin_schema,
         migrations=result.migrations,
     )
-    migration_error_msgs = await schema_apply_migrations(message=apply_migration_data, service=service)
+    migration_error_msgs = await schema_apply_migrations(message=apply_migration_data)
 
     if migration_error_msgs:
         rprint(f"{ERROR_BADGE} | Some error(s) happened while running the schema migrations")
