@@ -11,19 +11,20 @@ from infrahub.trigger.catalogue import builtin_triggers
 from infrahub.trigger.models import TriggerType
 from infrahub.trigger.setup import setup_triggers
 
-from .catalogue import worker_pools, workflows
+from .catalogue import WORKER_POOLS, get_workflows
 from .models import TASK_RESULT_STORAGE_NAME
 
 
 @task(name="task-manager-setup-worker-pools", task_run_name="Setup Worker pools", cache_policy=NONE)  # type: ignore[arg-type]
 async def setup_worker_pools(client: PrefectClient) -> None:
     log = get_run_logger()
-    for worker in worker_pools:
+    for worker in WORKER_POOLS:
         wp = WorkPoolCreate(
             name=worker.name,
             type=worker.worker_type or config.SETTINGS.workflow.default_worker_type,
             description=worker.description,
         )
+
         try:
             await client.create_work_pool(work_pool=wp, overwrite=True)
             log.info(f"Work pool {worker.name} created successfully ... ")
@@ -34,10 +35,10 @@ async def setup_worker_pools(client: PrefectClient) -> None:
 @task(name="task-manager-setup-deployments", task_run_name="Setup Deployments", cache_policy=NONE)  # type: ignore[arg-type]
 async def setup_deployments(client: PrefectClient) -> None:
     log = get_run_logger()
-    for workflow in workflows:
+    for workflow in get_workflows():
         # For now the workpool is hardcoded but
         # later we need to make it dynamic to have a different worker based on the type of the workflow
-        work_pool = worker_pools[0]
+        work_pool = WORKER_POOLS[0]
         await workflow.save(client=client, work_pool=work_pool)
         log.info(f"Flow {workflow.name}, created successfully ... ")
 
